Merlon
======

Merlon is a mod package manager for the Paper Mario (N64) decompilation.

Merlon is also available as a Rust crate: https://crates.io/crates/merlon

.. toctree::
   :maxdepth: 1

   api
